==> nb_utils-3.0.9%2B2.tar.gz: lib/src/string_extensions.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

extension StringExtension on String {
  /// Check email validation
  bool validateEmail() => RegExp(
          r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+")
      .hasMatch(this);

  /// Check phone validation
  bool validatePhone() => RegExp(r'(^(?:[+0]9)?[0-9]{10,12}$)').hasMatch(this);

  /// Check URL validation
  bool validateURL() {
    return RegExp(
            r'^((?:.|\n)*?)((http:\/\/www\.|https:\/\/www\.|http:\/\/|https:\/\/)?[a-z0-9]+([\-\.]{1}[a-z0-9]+)([-A-Z0-9.]+)(/[-A-Z0-9+&@#/%=~_|!:,.;]*)?(\?[A-Z0-9+&@#/%=~_|!:‌​,.;]*)?)')
        .hasMatch(this);
  }

  /// Returns true if given String is null or isEmpty
  bool get isEmptyOrNull => this == null || isEmpty;

  // Check null string, return given value if null
  String validate({String value = ''}) => this ?? value;

  /// Capitalize given String
  String capitalizeFirstLetter() => (validate().length >= 1)
      ? (substring(0, 1).toUpperCase() + substring(1).toLowerCase())
      : validate();

  /// Return true if given String is Digit
  bool isDigit(String s) {
    if (s.isEmpty) {
      return false;
    }
    if (s.length > 1) {
      for (var r in s.runes) {
        if (r ^ 0x30 > 9) {
          return false;
        }
      }
      return true;
    } else {
      return s.runes.first ^ 0x30 <= 9;
    }
  }

  /// Print given String
  log() {
    var dateTime = DateTime.now();
    print('${dateTime.hour}:${dateTime.minute}:${dateTime.second} $this');
  }

  // Copy String to Clipboard
  copyToClipboard() async {
    if (this == null || this.length <= 0) return;
    await Clipboard.setData(ClipboardData(text: this));
  }

  Text text({
    String defaultValue = '',
    TextStyle style,
    int maxLines,
    TextOverflow overflow = TextOverflow.ellipsis,
    TextAlign textAlign,
    bool softWrap,
    Locale locale,
    Key key,
    String semanticsLabel,
    StrutStyle strutStyle,
    TextDirection textDirection,
    double textScaleFactor,
    TextWidthBasis textWidthBasis,
  }) {
    return Text(
      this.validate(value: defaultValue),
      style: style,
      maxLines: maxLines,
      overflow: overflow,
      textAlign: textAlign,
      softWrap: softWrap,
      locale: locale,
      key: key,
      semanticsLabel: semanticsLabel,
      strutStyle: strutStyle,
      textDirection: textDirection,
      textScaleFactor: textScaleFactor,
      textWidthBasis: textWidthBasis,
    );
  }
}

==> nb_utils-3.1.6%2B2.tar.gz: lib/src/string_extensions.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

RegExp alpha = RegExp(r'^[a-zA-Z]+$');

extension StringExtension on String {
  /// Check email validation
  bool validateEmail() => RegExp(
          r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+")
      .hasMatch(this);

  /// Check phone validation
  bool validatePhone() => RegExp(r'(^(?:[+0]9)?[0-9]{10,12}$)').hasMatch(this);

  /// Check URL validation
  bool validateURL() {
    return RegExp(
            r'^((?:.|\n)*?)((http:\/\/www\.|https:\/\/www\.|http:\/\/|https:\/\/)?[a-z0-9]+([\-\.]{1}[a-z0-9]+)([-A-Z0-9.]+)(/[-A-Z0-9+&@#/%=~_|!:,.;]*)?(\?[A-Z0-9+&@#/%=~_|!:‌​,.;]*)?)')
        .hasMatch(this);
  }

  /// Returns true if given String is null or isEmpty
  bool get isEmptyOrNull => this == null || isEmpty;

  // Check null string, return given value if null
  String validate({String value = ''}) {
    if (this == null) {
      return value;
    } else {
      if (this == 'null') {
        return value;
      } else {
        return this;
      }
    }
  }

  /// Capitalize given String
  String capitalizeFirstLetter() => (validate().length >= 1)
      ? (substring(0, 1).toUpperCase() + substring(1).toLowerCase())
      : validate();

  /// Return true if given String is Digit
  bool isDigit() {
    if (this.isEmpty) {
      return false;
    }
    if (this.length > 1) {
      for (var r in this.runes) {
        if (r ^ 0x30 > 9) {
          return false;
        }
      }
      return true;
    } else {
      return this.runes.first ^ 0x30 <= 9;
    }
  }

  /// Print given String
  log() {
    var dateTime = DateTime.now();
    print('${dateTime.hour}:${dateTime.minute}:${dateTime.second} $this');
  }

  // Copy String to Clipboard
  void copyToClipboard() async {
    if (this == null || this.length <= 0) return;
    await Clipboard.setData(ClipboardData(text: this));
  }

  Text text({
    String defaultValue = '',
    TextStyle style,
    int maxLines,
    TextOverflow overflow = TextOverflow.ellipsis,
    TextAlign textAlign,
    bool softWrap,
    Locale locale,
    Key key,
    String semanticsLabel,
    StrutStyle strutStyle,
    TextDirection textDirection,
    double textScaleFactor,
    TextWidthBasis textWidthBasis,
  }) {
    return Text(
      this.validate(value: defaultValue),
      style: style,
      maxLines: maxLines,
      overflow: overflow,
      textAlign: textAlign,
      softWrap: softWrap,
      locale: locale,
      key: key,
      semanticsLabel: semanticsLabel,
      strutStyle: strutStyle,
      textDirection: textDirection,
      textScaleFactor: textScaleFactor,
      textWidthBasis: textWidthBasis,
    );
  }

  String convertUrlToId({bool trimWhitespaces = true}) {
    String url = this;
    assert(url?.isNotEmpty ?? false, 'Url cannot be empty');
    if (!url.contains("http") && (url.length == 11)) return url;
    if (trimWhitespaces) url = url.trim();

    for (var exp in [
      RegExp(
          r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"),
      RegExp(
          r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"),
      RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")
    ]) {
      Match match = exp.firstMatch(url);
      if (match != null && match.groupCount >= 1) return match.group(1);
    }

    return null;
  }

  bool isAlpha() {
    return alpha.hasMatch(this);
  }

  bool isJson() {
    try {
      json.decode(this);
    } catch (e) {
      return false;
    }
    return true;
  }

  String formatNumberWithComma() {
    return this.replaceAllMapped(
        RegExp(r'(\d{1,3})(?=(\d{3})+(?!\d))'), (Match m) => '${m[1]},');
  }
}
